@@ -8,6 +8,9 @@ import {
   TimeSeries,
   TableData,
   toDataFrame,
+  DataFrame,
+  MetricFindValue,
+  FieldType,
 } from '@grafana/data';
 
 interface DataResponse {
@@ -19,7 +22,9 @@ interface DataResponse {
 }
 
 /**
- * Parse the results from `/api/ds/query
+ * Parse the results from /api/ds/query into a DataQueryResponse
+ *
+ * @public
  */
 export function toDataQueryResponse(res: any): DataQueryResponse {
   const rsp: DataQueryResponse = { data: [], state: LoadingState.Done };
@@ -91,6 +96,8 @@ export function toDataQueryResponse(res: any): DataQueryResponse {
 /**
  * Convert an object into a DataQueryError -- if this is an HTTP response,
  * it will put the correct values in the error field
+ *
+ * @public
  */
 export function toDataQueryError(err: any): DataQueryError {
   const error = (err || {}) as DataQueryError;
@@ -115,3 +122,26 @@ export function toDataQueryError(err: any): DataQueryError {
 
   return error;
 }
+
+/**
+ * Return the first string or non-time field as the value
+ *
+ * @beta
+ */
+export function frameToMetricFindValue(frame: DataFrame): MetricFindValue[] {
+  if (!frame || !frame.length) {
+    return [];
+  }
+
+  const values: MetricFindValue[] = [];
+  let field = frame.fields.find((f) => f.type === FieldType.string);
+  if (!field) {
+    field = frame.fields.find((f) => f.type !== FieldType.time);
+  }
+  if (field) {
+    for (let i = 0; i < field.values.length; i++) {
+      values.push({ text: '' + field.values.get(i) });
+    }
+  }
+  return values;
+}
